@@ -180,8 +180,8 @@ function copyReleaseFrameworkFiles(){
     var frameworkReleasePath = config.workCopyFilesTemplatePath() + "/release/";
     xtools.copyDirEx(frameworkReleasePath,config.targetReleasePackagePath());
 
-    var frameworkThemePath = config.workCopyFilesTemplatePath() + "/dev-server/";
-    xtools.copyDirEx(frameworkThemePath,config.targetDevelopServerPath());
+    //var frameworkThemePath = config.workCopyFilesTemplatePath() + "/dev-server/";
+    //xtools.copyDirEx(frameworkThemePath,config.targetDevelopServerPath());
 
 }
 
