@@ -17,6 +17,7 @@ var config = {
     framework:"simple",
     basePackage:"com.simple.base.bz",
     apiServer:"",
+    defines:null,
 
     //当前工作目录下的模块定义目录
     workModulesPath: function(){return path.join(this.workRootPath , "modules/")},
@@ -129,20 +130,36 @@ function createReleasePackageFiles(){
 
 };
 
+function buildParams(moduleName,moduleDefine){
+    var params = config.buildBaseParams();
+    params.moduleDefine = moduleDefine;
+    params.moduleName = moduleName;
+    params.moduleClassName = codeTools.firstUpper(moduleName);
+    params.packageName = config.basePackage;
+    params.firstUpper = codeTools.firstUpper;
+    params.refers = [];
+    params.fields = [];
+    for (var field in moduleDefine){
+        var fieldDef  = moduleDefine[field];
+        if (fieldDef.refer){
+            var refer = fieldDef.refer;
+            var referModule = refer.module;
+            var referMap   = refer.map;
+            var referModuleClass = codeTools.firstUpper(referModule);
+            params.refers.push({module:referModule,cls:referModuleClass,map:referMap});
+        }
+        params.fields.push({def:fieldDef,name:field,cls:codeTools.firstUpper(field)});
+    }
+    return params;
+}
 function createModel(moduleName,moduleDefine){
     var filename =  "model.js";
     var tFilename = filename;
     var templateFile = config.workModelTemplatePath() + filename;
     var moduleFile   = config.targetModuleModelPath() + tFilename ;
-    var params = config.buildBaseParams();
+    var params = buildParams(moduleName,moduleDefine);
     codeTools.generateCode(templateFile,params,moduleFile);
 
-    //filename =  "modelBase.js";
-    //tFilename = filename;
-    //var templateFile = config.workModelTemplatePath() + filename;
-    //var moduleFile   = config.targetModuleModelPath() + tFilename ;
-    //codeTools.generateCode(templateFile,params,moduleFile);
-
 };
 function createFunctionViewAndController(fName, moduleName,moduleDefine){
     var filename =  fName + ".js";
@@ -150,8 +167,7 @@ function createFunctionViewAndController(fName, moduleName,moduleDefine){
 
     templateFile = config.workControllerTemplatePath() + tFilename ;
     moduleFile   = config.targetModuleControllerPath() + filename;
-    var params = config.buildBaseParams();
-    params.moduleDefine = moduleDefine;
+    var params = buildParams(moduleName,moduleDefine);
     codeTools.generateCode(templateFile,params,moduleFile);
 };
 
@@ -159,17 +175,12 @@ function createFunctionViewAndController(fName, moduleName,moduleDefine){
 function createModuleBaseDirectories(moduleName){
     xtools.mkdirX(config.targetWebResourceRootPath());
     codeTools.createDirectory(config.targetModuleRootPath());
-    //codeTools.createDirectory(config.targetModuleViewTemplatePath());
     codeTools.createDirectory(config.targetModuleControllerPath());
     codeTools.createDirectory(config.targetModuleModelPath());
     codeTools.createDirectory(config.targetModuleRouterPath());
     codeTools.createDirectory(config.targetModuleConfigPath());
     codeTools.createDirectory(config.targetModuleComponentsPath());
     codeTools.createDirectory(config.targetWebResourceCommonPath());
-    //codeTools.createDirectory(config.targetModuleReduxPath());
-    //codeTools.createDirectory(path.join(config.targetModuleReduxPath(),'actions/'));
-    //codeTools.createDirectory(path.join(config.targetModuleReduxPath(),'reducers/'));
-
 
 }
 function generateFrameworkDirectories(){
@@ -192,13 +203,9 @@ function generateClientModule(moduleName,moduleDefine){
     createFunctionViewAndController("add",moduleName,moduleDefine);
     createFunctionViewAndController("edit",moduleName,moduleDefine);
     createFunctionViewAndController("list",moduleName,moduleDefine);
-    createFunctionViewAndController("info",moduleName,moduleDefine);
-    createFunctionViewAndController("home",moduleName,moduleDefine);
-    //createFunctionViewAndController("NotFound",moduleName,moduleDefine);
-    //createFunctionViewAndController("app",moduleName,moduleDefine);
+    createFunctionViewAndController("detail",moduleName,moduleDefine);
+    //createFunctionViewAndController("home",moduleName,moduleDefine);
 
-    //redux
-   // createClientReduxFlow();
 }
 
 function initPathEnv(defines){
@@ -216,6 +223,7 @@ function initPathEnv(defines){
     config.basePackage = defines.basePackage;
     config.apiServer = defines.apiServer;
     config.endName = "client";
+    config.defines = defines;
     console.log("workRootPath:" + config.workRootPath + "Code-targetServerPath:" + config.targetRootPath);
 
 
@@ -223,10 +231,10 @@ function initPathEnv(defines){
 
 
 function copyFrameworkFiles(){
-    var frameworkThemePath = config.workCopyFilesTemplatePath() + "resources/coreModules/user/";
-    xtools.copyDirEx(frameworkThemePath,config.targetWebResourceRootPath() + "/user/");
+    var frameworkThemePath = config.workCopyFilesTemplatePath() + "resources/coreModules/"+config.endName+ "/";
+    xtools.copyDirEx(frameworkThemePath,config.targetWebResourceRootPath() + "/");
 
-    var commonPath = config.workCopyFilesTemplatePath() + "/common/";
+    var commonPath = config.workCopyFilesTemplatePath() + "/common/" + config.endName + "/";
     xtools.copyDirEx(commonPath,config.targetWebResourceCommonPath());
 
 }
@@ -236,8 +244,8 @@ function copyReleaseFrameworkFiles(){
     var frameworkReleasePath = config.workCopyFilesTemplatePath() + "/release/";
     xtools.copyDirEx(frameworkReleasePath,config.targetReleasePackagePath());
 
-    var frameworkThemePath = config.workCopyFilesTemplatePath() + "/dev-server/";
-    xtools.copyDirEx(frameworkThemePath,config.targetDevelopServerPath());
+    //var frameworkThemePath = config.workCopyFilesTemplatePath() + "/dev-server/";
+    //xtools.copyDirEx(frameworkThemePath,config.targetDevelopServerPath());
 }
 function generateModuleByName(moduleName,defines,sideName){
     //initPathEnv(defines);
