@@ -1,6 +1,6 @@
 module.exports  ={
     enables:["product","dictionary","category","level"],
-    basePackage:"com.simple.server.bz.auto",
+    basePackage:"com.simple.server.auto",
     apiServer:"http://api.zhangyongqiao.com",
 }
 
