@@ -12,9 +12,13 @@ var cfg = Object.assign(webpackBaseConfig, {
     devtool: "cheap-module-eval-source-map"
 });
 
+const pxtorem = require('postcss-pxtorem');
+
+
+
 process.env.NODE_ENV = 'development';
 // 模块名称, 替换此处以便启动并开发对应模块
-var projectModule = 'admin/product';
+var projectModule = 'client/product';
 
 
 var config = {
@@ -33,7 +37,7 @@ var config = {
     },
 
     babel: {
-        //presets: ['es2015', 'stage-0', 'react'],
+
         presets: ['es2015', 'react', 'stage-1'],
         "plugins": [["react-transform", {
             "transforms": [{
@@ -46,11 +50,19 @@ var config = {
             // note: you can put more transforms into array
             // this is just one of them!
         }],
-            ['import', {
+            ['import', [{
             libraryName: 'antd',
             style: 'css'
-        }]]
+        },{
+                "libraryName": "antd-mobile",
+                "style": 'css'
+            },{
+                libraryName: "material-ui",
+                libraryDirectory:'components',
+                camel2DashComponentName:false,
+            }]]]
     },
+    devtool: 'eval',
     externals: webpackBaseConfig.externals,
 
     //插件项
